@@ -22,10 +22,11 @@
 # 
 
 import iso8601
+import logger
 
 class Event:
 	def __init__(self, title, where, descr, start_time, end_time, \
-			full_day, id, cdate, rrule=""):
+			full_day, id, cdate, rrule=None):
 		self.title = title
 		self.where = where
 		self.descr = descr
@@ -79,20 +80,25 @@ class Event:
 		return int(self.cdate)
 
 	def get_until(self):
-		if self.rrule == "":
+		if self.rrule == None:
 			return -1
 
 		rules = self.rrule.split(";")
+		print rules
 		d = ""
 		for r in rules:
 			if r.startswith("UNTIL="):
 				d = r[len("UNTIL="):]
+				break
 
 		if len(d) == 8:
 			iso_date = d[:4] + "-" + d[4:6] + "-" + d[6:]
-		else:
+		elif len(d) == 15:
 			iso_date = d[:4] + "-" + d[4:6] + "-" + d[6:11] \
 					+ ":" + d[11:13] + ":" + d[13:]
+		else:
+			logger.append("event %s: strange until value: %s" % (self.title, d))
+			return -1
 
 		# ??
 		return int(iso8601.parse(iso_date)) + 1
