@@ -287,6 +287,10 @@ def update_remote_data_source(sync_type, google_acct_id):
 		google_new_btn.set_sensitive(True)
 		google_item_picker.set_sensitive(True)
 		for id, title in google_api.get_all_calendars():
+			logger.append("ID->")
+			logger.append(id)
+			logger.append("title->")
+			logger.append(title)
 			remote_sources.append([id, title])
 		hildon.hildon_gtk_window_set_progress_indicator(dialog, 0)
 
